Attribute VB_Name = "modQuickDirTree"
Option Explicit

Sub CreateFolderTree()
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' CreateFolderTree
' By Chip Pearson, chip@cpearson.com , www.cpearson.com
' This creates a hierarchical directory listing tree.
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

Dim FSO As Scripting.FileSystemObject
Dim FolderName As String
Dim StartFolder As Scripting.Folder
Dim SubF As Scripting.Folder
Dim F As Scripting.File
Dim R As Range
Dim Indent As Boolean
Dim FullPaths As Boolean

Set FSO = New Scripting.FileSystemObject
' Prompt the user for the top level directory.
FolderName = InputBox("Enter the top folder of the directory tree")
' Get out if no file was selected.
If Trim(FolderName) = vbNullString Then
    Exit Sub
Else
    If Dir(FolderName, vbDirectory) = vbNullString Then
        Exit Sub
    End If
End If

Set StartFolder = FSO.GetFolder(FolderName)
' Change the reference held by R to the first cell of the results tree.
Set R = ActiveSheet.Range("A1")
' Indent = True creates an indented list showing the hierarchical nature
' of the folders. Indent = False creates a single column list.
Indent = True
' FullPaths = True lists the fully qualified directory name. FullPaths = False
' lists the directory name only, with no path information.
FullPaths = True
' Start the process
DoOneFolder WhatFolder:=StartFolder, WriteTo:=R, Indent:=Indent, FullPaths:=FullPaths

End Sub

Sub DoOneFolder(WhatFolder As Scripting.Folder, WriteTo As Range, _
        Optional Indent As Boolean = False, _
        Optional FullPaths As Boolean = False)

Dim SubF As Scripting.Folder
' Write the path that was passed in.
If FullPaths = True Then
    WriteTo.Value = WhatFolder.Path
Else
    WriteTo.Value = WhatFolder.Name
End If

' move the target cell down one row
Set WriteTo = WriteTo(2, 1)

For Each SubF In WhatFolder.SubFolders
    ' For every subfolder in WhatFolder, call this
    ' same procedure passing it the file name. This
    ' recursion spans the entire directory tree.
    If Indent = True Then
        Set WriteTo = WriteTo(1, 2)
    End If
    If FullPaths = True Then
        WriteTo.Value = SubF.Path
    Else
        WriteTo.Value = SubF.Name
    End If
        
    ' Call ourself using SubF.
    DoOneFolder WhatFolder:=SubF, WriteTo:=WriteTo, Indent:=Indent, FullPaths:=FullPaths
    
    If Indent = True Then
        Set WriteTo = WriteTo(1, 0)
    End If
Next SubF



End Sub
